# xradar

[![PyPI Version](https://img.shields.io/pypi/v/xradar.svg)](https://pypi.python.org/pypi/xradar)
[![RTD Version](https://readthedocs.org/projects/xradar/badge/?version=latest)](https://xradar.readthedocs.io/en/latest/?version=latest)


Xradar includes all the tools to get your weather radar into the xarray data model.

* Free software: MIT license
* Documentation: https://xradar.readthedocs.io.


## Features

* TODO
